#include <lum-cd-selection.h>
#include <lum-changer.h>
#include <lum-skin.h>
#include <lum-skin-hslider.h>
#include <lum-skin-number.h>
#include <lum-skin-pbutton.h>
#include <lum-skin-button.h>
#include <lum-skin-widget.h>
#include <lum-skin-playstatus.h>
#include <lum-skin-textbox.h>
#include <lum-skin-tbutton.h>
#include <lum-skin-menurow.h>
#include <lum-skin-monostereo.h>
#include <lum-skin-eventhandler.h>
#include <lum-player.h>           
#include <lum-player-info.h>
#include <lum-player-info-server.h>
#include <lum-automation.h>
#include <lum-playlist.h>
#include <lum-playlist-store.h>
#include <lum-config.h>
#include <lum-prefs.h>
#include <lum-context.h>
#include <lum-session.h>
#include <lum-control.h>
#include <lum-shell.h>
#include <lum-util.h>
#include <lum-engine.h>
#include <lum-engine-server.h>
#include <hig-alert.h>
#include <eggtrayicon.h>
#include <eggtreemultidnd.h>
#include <LumAutomation.h>
#include <LumEngine.h>
#include <LumPlayerInfo.h>
#include <GNOME_Speech_SynthesisDriver.h>
#ifdef ENABLE_GLPLAY
#include <lum-glplay.h>
#include <rgb2rgb.h>
#include <mangle.h>
#endif
#ifdef ENABLE_XINE
#include <gtk-xine.h>
#include <gtk-xine-info.h>
#include <gtk-xine-widget.h>
#endif
#ifdef ENABLE_MPLAYER
#include <gtk-player.h>
#endif
